@@ -29,7 +29,7 @@ def create_new_project(session):
 
     clearConsole()
     num = get_latest_proj()
-    team = [t for t in projects if option.lower() in t["name"].lower()][0]
+    team = [t for t in projects if option.lower() == t["name"].lower()][0]
     print(f"💁‍♂️ Making a new project for {team['name']}")
 
     dest_folder = None
